import { CoreDaemon } from './core.js';
import { CoreWallet } from './wallet.js';
import { TxBytes, TxData } from '@scrow/tapscript';
import { BlockQuery, ClientConfig, MethodArgs, ScanAction, ScanObject, ScanResults, CoreConfig, CmdConfig, TxStatus, BlockData, BlockHeader } from '../types/index.js';
export declare class CoreClient {
    readonly _core: CoreDaemon;
    readonly _opt: CoreConfig;
    params: string[];
    _cache: [string, unknown];
    _faucet: CoreWallet | null;
    constructor(core: CoreDaemon, config?: Partial<ClientConfig>);
    get opt(): CoreConfig;
    get chain_info(): Promise<Record<string, any>>;
    get core(): CoreDaemon;
    get wallets_loaded(): Promise<string[]>;
    get wallets_created(): Promise<string[]>;
    cmd<T = Record<string, string>>(method: string, args?: MethodArgs, config?: Partial<CmdConfig>): Promise<T>;
    _get_block_data(query: BlockQuery, txdata?: boolean): Promise<BlockHeader>;
    get_block(query: BlockQuery): Promise<BlockData>;
    get_header(query: BlockQuery): Promise<BlockHeader>;
    scan_txout(action: ScanAction, ...desc: (string | ScanObject)[]): Promise<ScanResults>;
    scan_addr(addr: string): Promise<import("../types/scan.js").UTXOResult[]>;
    mine_blocks(count?: number, addr?: string): Promise<Record<string, string>>;
    get_tx(txid: string): Promise<{
        data: {
            blockhash: string;
            confirmations: number;
            time: number;
            blocktime: number;
            txid: string;
            hash: string;
            version: number;
            size: number;
            vsize: number;
            weight: number;
            locktime: number;
            vin: [{
                txid: string;
                vout: number;
                scriptSig: {
                    asm: string;
                    hex: string;
                };
                txinwitness: string[];
                sequence: number;
            }];
            vout: [{
                n: number;
                value: number;
                scriptPubKey: import("../types/info.js").ScriptKeyResult;
            }];
        } | {
            blockhash?: string | undefined;
            confirmations?: number | undefined;
            time?: number | undefined;
            blocktime?: number | undefined;
            txid: string;
            hash: string;
            version: number;
            size: number;
            vsize: number;
            weight: number;
            locktime: number;
            vin: [{
                txid: string;
                vout: number;
                scriptSig: {
                    asm: string;
                    hex: string;
                };
                txinwitness: string[];
                sequence: number;
            }];
            vout: [{
                n: number;
                value: number;
                scriptPubKey: import("../types/info.js").ScriptKeyResult;
            }];
        };
        hex: string;
        status: TxStatus;
    } | null>;
    load_wallet(name: string): Promise<CoreWallet>;
    load_wallets(...labels: string[]): Promise<Record<string, CoreWallet>>;
    publish_tx(txdata: TxBytes | TxData, confirm?: boolean): Promise<string>;
}
//# sourceMappingURL=client.d.ts.map